@@ -1,4 +1,3 @@
-## Main function
 #' Ordinal regression models with elastic net penalty
 #'
 #' Fits ordinal regression models with elastic net penalty by coordinate descent.
@@ -107,8 +106,8 @@
 #' monotone increasing."
 #' The warning is displayed by default, but the user may wish to disable it.
 #' @param keepTrainingData Logical. If \code{TRUE}, then \code{x} and \code{y}
-#' are saved with the returned "ordinalNetFit" object. This allows
-#' \code{predict.ordinalNetFit} to return fitted values for the training data
+#' are saved with the returned "ordinalNet" object. This allows
+#' \code{predict.ordinalNet} to return fitted values for the training data
 #' without passing a \code{newx} argument.
 
 #' @details
@@ -193,7 +192,7 @@
 #' when \code{y} is a matrix.
 #' \deqn{objective = -1/N*loglik + penalty}
 #'
-#' @return An object with S3 class "ordinalNetFit".  Model fit information can be accessed
+#' @return An object with S3 class "ordinalNet".  Model fit information can be accessed
 #' through the \code{coef}, \code{predict}, and \code{summary} methods.
 #' \describe{
 #'   \item{coefs}{Matrix of coefficient estimates, with each row corresponding to a lambda value.
@@ -414,10 +413,10 @@ ordinalNet <- function(x, y, alpha=1, standardize=TRUE, penaltyFactors=NULL, pos
     loglikNull <- getLoglikNull(yMat)
     devPct <- 1 - loglik / loglikNull
 
-    ordinalNetFit <- list(coefs=coefs, lambdaVals=lambdaVals, loglik=loglik,
-                          nNonzero=nNonzero, aic=aic, bic=bic, devPct=devPct,
-                          iterOut=iterOut, iterIn=iterIn, dif=dif,
-                          nLev=nLev, nVar=nVar, xNames=xNames, args=args)
-    class(ordinalNetFit) <- "ordinalNetFit"
-    ordinalNetFit
+    fit <- list(coefs=coefs, lambdaVals=lambdaVals, loglik=loglik,
+                nNonzero=nNonzero, aic=aic, bic=bic, devPct=devPct,
+                iterOut=iterOut, iterIn=iterIn, dif=dif,
+                nLev=nLev, nVar=nVar, xNames=xNames, args=args)
+    class(fit) <- "ordinalNet"
+    fit
 }
